EasyExtend.langlets.p4d.p4dbase

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase |
[hide private]
[frames] | no frames]

# Module p4dbase

Classes | [hide private]
| FileLike
| P4DAccessError
| P4DContentList
| P4DList Class used to represent lists of P4D objects.
| P4DName
| P4DAttributes
| P4DNamespace
| P4D P4D objects are lazy wrappers around nested lists that store XML or P4D data.
| _child_iter
| P4DNode Used to build list-trees from the bottom up.

Functions | [hide private]
prepare_text(text) |

Variables | [hide private]
| ALL = `0`
| IGNOREWHITESPACE = `True`